@@ -124,7 +124,7 @@ void doxschema(xcWidget w, pointertype mode, caddr_t calldata)
 /* Find the page object and instance with the indicated name.		*/
 /*----------------------------------------------------------------------*/
 
-objectptr NameToPageObject(char *objname, objinstptr *ret_inst)
+objectptr NameToPageObject(char *objname, objinstptr *ret_inst, int *ret_page)
 {
    int i;
 
@@ -132,6 +132,7 @@ objectptr NameToPageObject(char *objname, objinstptr *ret_inst)
       if (xobjs.pagelist[i]->pageinst == NULL) continue;
       if (!strcmp(objname, xobjs.pagelist[i]->pageinst->thisobject->name)) {
 	 if (ret_inst) *ret_inst = xobjs.pagelist[i]->pageinst;
+	 if (ret_page) *ret_page = i;
 	 return xobjs.pagelist[i]->pageinst->thisobject;
       }
    }
@@ -157,7 +158,7 @@ objectptr NameToObject(char *objname, objinstptr *ret_inst, Boolean dopages)
    }
 
    if (dopages)
-      return NameToPageObject(objname, ret_inst);
+      return NameToPageObject(objname, ret_inst, NULL);
    else
       return NULL;
 }
@@ -243,8 +244,9 @@ void startconnect(xcWidget button, caddr_t clientdata, caddr_t calldata)
 
 void connectivity(xcWidget button, caddr_t clientdata, caddr_t calldata)
 {
-   short *gsel;
-   genericptr ggen;
+   short *gsel = NULL;
+   selection *rselect = NULL, *nextselect;
+   genericptr ggen = NULL;
    Genericlist *netlist = NULL;
    int depth, lbus, netid, subnetid;
    buslist *sbus;
@@ -275,12 +277,23 @@ void connectivity(xcWidget button, caddr_t clientdata, caddr_t calldata)
 	    if (!nonnetwork(gpoly)) break;
 	 }
       }
-      if (gsel == areastruct.selectlist + areastruct.selects) {
-	 Wprintf("Selected element is not part of a valid network.");
+   }
+   if ((areastruct.selects == 0) || (gsel == areastruct.selectlist
+		+ areastruct.selects)) {
+      rselect = recurselect(POLYGON | LABEL | OBJINST, MODE_CONNECT, &seltop);
+      /* Should look at the top scorer, when scoring has been implemented */
+      if (rselect && (rselect->selects > 0)) {
+	 for (nextselect = rselect; (nextselect->next != NULL) &&
+		(nextselect->selects > 0); nextselect = nextselect->next);
+         ggen = *(nextselect->thisinst->thisobject->plist + *(nextselect->selectlist));
+	 while (rselect != NULL) {
+	    nextselect = rselect->next;
+	    free(rselect);
+            free(rselect->selectlist);
+	    rselect = nextselect;
+	 }
       }
    }
-   else
-      ggen = recurselect(POLYGON | LABEL, &seltop);
 
    /* Determine the net and the topmost object in which that	*/
    /* net appears.  Then build the transformation matrix down	*/
@@ -658,6 +671,7 @@ void collectsubschems(int toppage)
    findsubschems(loctop, cschem, 0, pagelist);
 
    for (pageno = 0; pageno < xobjs.pages; pageno++) {
+      if (pageno == loctop) continue;
       if (pagelist[pageno] > 0) {
 	  if (xobjs.pagelist[pageno]->filename != NULL)
 	     free(xobjs.pagelist[pageno]->filename);
@@ -773,8 +787,7 @@ int checksym(objectptr symobj, char *cname)
 
 /*----------------------------------------------------------------------*/
 /* Find location of corresponding pin in symbol/schematic and change it */
-/* to the text of the indicated label.  If "newlabel" is NULL, then	*/
-/* change the other label from pin to normal text.			*/
+/* to the text of the indicated label.					*/
 /*----------------------------------------------------------------------*/
 
 void changeotherpins(labelptr newlabel, stringpart *oldstring)
@@ -788,13 +801,12 @@ void changeotherpins(labelptr newlabel, stringpart *oldstring)
    for (tgen = other->plist; tgen < other->plist + other->parts; tgen++) {
       if (IS_LABEL(*tgen)) {
 	 tlab = TOLABEL(tgen);
+	 if (tlab->pin != LOCAL) continue;
 	 if (!stringcomp(tlab->string, oldstring)) {
 	    if (newlabel != NULL) {
 	       free(tlab->string);
 	       tlab->string = stringcopy(newlabel->string);
 	    }
-	    else
-	       tlab->pin = NORMAL;
 	 }
       }
    }
@@ -855,7 +867,6 @@ void swapschem(xcWidget w, pointertype mode, caddr_t calldata)
 	 initmem(*newobject);
 	 (*newobject)->schemtype = SYMBOL;
 	 (*newobject)->hidden = False;
-	 (*newobject)->devname = NULL;
 
 	 incr_changes(*newobject);
 
