@@ -222,6 +222,12 @@ stringpart *nextstringpart(stringpart *strptr, objinstptr thisinst)
 	 strptr->data.string = (u_char *)NULL;
       }
    }
+
+   /* Sanity check */
+   if (nextptr == strptr) {
+      fprintf(stderr, "Internal error:  Self-referencing string!\n");
+      return NULL;
+   }
    return nextptr;
 }
 
@@ -418,6 +424,12 @@ stringpart *linkstring(objinstptr localinst, stringpart *strstart,
    else
       nextptr = ops->parameter.string;
 
+   /* Sanity check */
+   if (nextptr == strstart) {
+      fprintf(stderr, "Internal error:  Self-referencing string!\n");
+      return NULL;
+   }
+
    /* If the parameter exists, link the end of the parameter back to	*/
    /* the calling string.						*/
 
